###################################################################
#
# created by Janna Willoughby, janna.willoughby@gmail.com
# script created in version R 3.1.1
# generates model output for RRS bias manscript, J of Heredity 2017
# notes: set all parameters below and then source this file
#
###################################################################
setwd("~/model2.8B/")
directory = getwd()
outdir    = paste(directory,"/output/",sep="")                    #directory to save model output  
source(paste(directory, "/source/FunctionSourcer.R", sep = ''))   #source functions and set source directory

repeats = 1                         #number of time to repeat simulations
plotit  = 1                         #toggle plotting 0=off, 1=on

#species parameters
species     = "salmon"              #species label
fecundity.V = 500                   #maximum fecundity, modified by RRS for each pair
maturity.V  = 4                     #maturity, number of years to reach sexual maturity
lifespan.V  = 7                     #maximum lifespan 
repro1.V    = 0                     #can individuals reproduce multiple times in a lifetime? 1 = yes, 0 = no
K.V         = 500                   #K, carrying capacity

#variables
N.V          = K.V                  #Intial population size                                             
gens.V       = 250                  #number years to simulate plus lifespan                             
RRS.V        = seq(0,1,0.1)         #relative reproductive success penelty for captive born individuals 
RRSvar.V     = 0.005                #variance in repro success, initiated when RRS is assigned 
r0.V         = 0.1                  #per capita growth rate
l.V          = 5                    #adult density independent mortality 
nloci.V      = 50                   #number of loci                                 
countimmat.V = 1                    #count immature individuals in Nt? 0 = no, 1 = yes
killimmat.V  = 1                    #kill immature in adult mortality step? 0 = no, 1 = yes
adultmort.V  = (1/(lifespan.V-2))   #proportion of adults that die after reproduction each year


#variables for captive breeding
startcap.V  = c(75,1000)            #year to start introduction of captive individuals (first release and control)
endcap.V    = 125                   #year to end introduction of captive individuals (first release time period)
startcap2.V = 150                   #year to start introduction of captive individuals (second release)
endcap2.V   = 200                   #year to end introduction of captive individuals (second release time period)
capfound.V  = 0.15                  #proportion of captive founders needed every generation
newfound.V  = 1                     #1=all new founders every generation, 0=some new some old
propnew.V   = 1                     #frequency to supplement/add individuals to popualtion
caplife.V   = 1*lifespan.V          #lifespan of captive individuals, relative to lifespan.V
coffprop.V  = 1                     #proportion of offspring from cap relative to wild

#control reproduction in captivity
equalcaptive.V  = 0                 #reproduction in captivity is divided equally (0=n, 1=y)
allonecaptive.V = 0                 #reproduction in captivity is all from one pair (0=n, 1=y)
capvariation.V  = 1                 #variation set up similar to wild, currently modified in code 

#environmental variables
poorenv.V   = 1000                     #generation to start removing individuals                        - 50
fixedenv.V  = 1000                     #generation to end removing individuals                          - 1000
lossperct.V = 0.5                      #proportion of individuals to remove                             - 0.5

#add migrants every year
nimmigrants.V = 1                      #number of effective migrants per generation                     - c(1,5,10)

#competition variable
propkill.V    = 0.5                    #proportion to assume die before Nt count                        - c(0,0.5,1) 

#selection
selection     = 0                      #switch for  selection (0 off, value = strength)                 - 0

runvars = Replicates(repeats, K.V, N.V, gens.V, RRS.V, RRSvar.V, r0.V, l.V, nloci.V, countimmat.V, killimmat.V, adultmort.V, fecundity.V, maturity.V, lifespan.V, repro1.V,
                     startcap.V, endcap.V, startcap2.V, endcap2.V, capfound.V, newfound.V, propnew.V, caplife.V, coffprop.V,poorenv.V, fixedenv.V, lossperct.V, nimmigrants.V, 
                     propkill.V, equalcaptive.V, allonecaptive.V, capvariation.V, directory, outdir, plotit, species, selection)

remove(repeats, K.V, N.V, gens.V, RRS.V, RRSvar.V, r0.V, l.V, nloci.V, countimmat.V, killimmat.V, adultmort.V, fecundity.V, maturity.V, lifespan.V, repro1.V,
       startcap.V, endcap.V, startcap2.V, endcap2.V, capfound.V, newfound.V, propnew.V, caplife.V, coffprop.V,poorenv.V, fixedenv.V, lossperct.V, nimmigrants.V,
       propkill.V, equalcaptive.V, allonecaptive.V, capvariation.V,directory, outdir, plotit, species, selection)

##run model iterating over parameters in Replicates
for(r in 1:nrow(runvars)){ 
  RunModel(runvars, r)
}
